@@ -3,17 +3,7 @@
 #include <signal.h>
 #include <termios.h>
 #include <ctype.h>
-
-#define _XOPEN_SOURCE 700
-#define _XOPEN_SOURCE_EXTENDED
-#define NCURSES_OPAQUE 1
-#ifdef __linux__
 #include <ncurses.h>
-#else
-#include <curses.h>
-#endif
-#undef _XOPEN_SOURCE
-#undef _XOPEN_SOURCE_EXTENDED
 #include <locale.h>
 #include <stdbool.h>
 #include <string.h>
@@ -715,8 +705,8 @@ void sexp_next()
     } else {			/* atom */
 	while (ed_data[ed_row][ed_col] != ' ' &&
 	       ed_data[ed_row][ed_col] != '(' &&
-	       ed_data[ed_row][ed_col] != ')' &&
-	       ed_data[ed_row][ed_col] != EOL) {
+	       ed_data[ed_row][ed_col] != ')'
+	       && ed_data[ed_row][ed_col] != EOL) {
 	    ed_col++;
 	    ed_col1++;
 	}
@@ -912,8 +902,8 @@ void sexp_prev()
 	}
     }
 
-    if (ed_data[ed_row][ed_col] == ')' &&
-	ed_data[ed_row][ed_col - 1] == ')') {
+    if (ed_data[ed_row][ed_col] == ')'
+	&& ed_data[ed_row][ed_col - 1] == ')') {
 	ed_col--;
     }
 
@@ -1251,6 +1241,8 @@ bool quit_with_save(void)
 	}
 	while (c != 'y' && c != 'n');
     }
+
+    return (false);
 }
 
 void save_file()
@@ -2602,7 +2594,7 @@ int find_eol(int row)
     int i;
 
     for (i = 0; i < COL_SIZE; i++) {
-	if (ed_data[row][i] == EOL)
+	if (ed_data[row][i] == EOL || ed_data[row][i] == 0)
 	    return (i);
     }
     return (-1);
