@@ -658,13 +658,28 @@ int signal_condition(int x, int y, int th)
 	fflush(stdout);
 	RAISE(Exit_Process);
     }
-    if (network_flag) {
+    if (child_flag) {
 	handling_resource_err = false;
 	signal_condition_x = x;
 	signal_condition_y = y;
 	printf("catch error\n");
-	send_to_parent(make_sym("\x15"));
-	RAISE(Exit_Network);
+	str = cdr(assoc(make_sym("a"), GET_CDR(x)));
+	args = cdr(assoc(make_sym("b"), GET_CDR(x)));
+	fun = cdr(assoc(make_sym("c"), GET_CDR(x)));
+	output_stream = error_stream;
+	if (repl_flag)
+	    ESCERRFRED();
+	fputs(GET_NAME(str), stderr);
+	print(fun);
+	fputc(' ', stderr);
+	print(args);
+	fputc('\n', stderr);
+	if (repl_flag)
+	    ESCERRFORG();
+	output_stream = standard_output;
+	int exp;
+	exp = list2(make_sym("dp-senderr"), make_int(child_id));
+	send_to_parent(sexp_to_str(exp));
     }
     if (open_flag && error_handler == NIL) {
 	fclose(GET_PORT(input_stream));
@@ -717,9 +732,9 @@ int signal_condition(int x, int y, int th)
     input_stream = standard_input;
     output_stream = standard_output;
     handling_resource_err = false;
-    if (!option_flag)
+    if (!option_flag && !child_flag)
 	debugger(th);
-    else {
+    else if (option_flag) {
 	puts("Error occurred while executing command line options.");
 	option_flag = false;
     }
